from typing import List
from enum import Enum, auto


class RunnerType(Enum):
    GENERIC = auto()
    LOCAL = auto()
    LOCALFLOW = auto()


def list_of_runners() -> List[str]:
    return sorted([runner_type.name.lower() for runner_type in RunnerType])
