NAME = "bluer_flow"

ICON = "📜"

DESCRIPTION = f"{ICON} Workflow management."

VERSION = "5.57.1"

REPO_NAME = "bluer-flow"

MARQUEE = "https://github.com/kamangir/assets/raw/main/bluer_flow-local-map-reduce/workflow.gif?raw=true"

ALIAS = "@flow"


def fullname() -> str:
    return f"{NAME}-{VERSION}"
